OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "无法写入 \"config\" 目录！",
    "This can usually be fixed by giving the web server write access to the config directory." : "通常可以为 Web 服务器授予对 config 目录的写入权限来修复这个问题。",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "但是，如果您更希望将 config.php 文件设为只读，可以将 \"config_is_read_only\" 选项设置为 true。",
    "See %s" : "查看 %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "应用程序%1$s不存在或其版本与此服务器不兼容。请检查应用目录。",
    "Sample configuration detected" : "示例配置检测",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "您似乎直接把 config.php 的样例文件直接复制使用。这可能会破坏您的安装。在对 config.php 进行修改之前请先阅读相关文档。",
    "The page could not be found on the server." : "无法在服务器上找到此页面",
    "%s email verification" : "%s 电子邮件验证",
    "Email verification" : "电子邮件验证",
    "Click the following button to confirm your email." : "点击下方按钮确认电子邮件地址",
    "Click the following link to confirm your email." : "点击下方链接确认电子邮件地址",
    "Confirm your email" : "确认电子邮件地址",
    "Other activities" : "其他动态",
    "%1$s and %2$s" : "%1$s 和 %2$s",
    "%1$s, %2$s and %3$s" : "%1$s，%2$s 和 %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s，%2$s，%3$s 和 %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s，%2$s，%3$s，%4$s 和 %5$s",
    "Education bundle" : "教育套餐",
    "Enterprise bundle" : "企业捆绑包",
    "Groupware bundle" : "群组捆绑包",
    "Hub bundle" : "枢纽捆绑包",
    "Public sector bundle" : "公共部门捆绑服务",
    "Social sharing bundle" : "社交共享捆绑包",
    "PHP %s or higher is required." : "要求 PHP 版本 %s 或者更高。",
    "PHP with a version lower than %s is required." : "需要版本低于 %s 的PHP。",
    "%sbit or higher PHP required." : "需要 %s 或更高版本的 PHP。",
    "The following architectures are supported: %s" : "支持以下架构：%s",
    "The following databases are supported: %s" : "支持以下数据库：%s",
    "The command line tool %s could not be found" : "命令行工具 %s 未找到",
    "The library %s is not available." : "库文件 %s 不可用",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "库版本 %1$s 高于需要的版本 %2$s - 可用版本 %3$s。",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "库版本 %1$s 低于需要的版本 %2$s - 可用版本 %3$s。",
    "The following platforms are supported: %s" : "支持以下平台：%s",
    "Server version %s or higher is required." : "需要服务器版本 %s 或更高版本。",
    "Server version %s or lower is required." : "需要服务器版本 %s 或更低版本。",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "登录的账户必须是管理员、副管理员或获得访问此设置的特殊权限",
    "Your current IP address doesn’t allow you to perform admin actions" : "您当前的 IP 地址不允许您执行管理员操作",
    "Logged in account must be an admin or sub admin" : "登录账户必须是管理员或副管理员",
    "Logged in account must be an admin" : "登录的账户必须是管理员",
    "Wiping of device %s has started" : "设备%s的擦除操作已开始",
    "Wiping of device »%s« has started" : "设备 »%s« 的擦除操作已开始",
    "»%s« started remote wipe" : "»%s« 已开始远程擦除",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "设备或应用程序 »%s« 已开始远程擦除进程。进程完成后您将收到另一封邮件。",
    "Wiping of device %s has finished" : "设备 %s 的擦除已完成",
    "Wiping of device »%s« has finished" : "设备 »%s« 的擦除操作已完成",
    "»%s« finished remote wipe" : "»%s« 已完成远程擦除",
    "Device or application »%s« has finished the remote wipe process." : "设备或应用程序 »%s« 已完成远程擦除进程。",
    "Remote wipe started" : "远程擦除开始",
    "A remote wipe was started on device %s" : "设备%s上一个远程擦除操作已开始",
    "Remote wipe finished" : "远程擦除完成",
    "The remote wipe on %s has finished" : "%s上的远程擦除操作已完成",
    "Authentication" : "验证",
    "Unknown filetype" : "未知的文件类型",
    "Invalid image" : "无效的图像",
    "Avatar image is not square" : "头像图像不是正方形",
    "Files" : "文件",
    "View profile" : "查看个人资料",
    "Local time: %s" : "当地时间：%s",
    "today" : "今天",
    "tomorrow" : "明天",
    "yesterday" : "昨天",
    "_in %n day_::_in %n days_" : ["%n天内"],
    "_%n day ago_::_%n days ago_" : ["%n 天前"],
    "next month" : "下月",
    "last month" : "上月",
    "_in %n month_::_in %n months_" : ["%n月内"],
    "_%n month ago_::_%n months ago_" : ["%n 月前"],
    "next year" : "明年",
    "last year" : "去年",
    "_in %n year_::_in %n years_" : ["%n年内"],
    "_%n year ago_::_%n years ago_" : ["%n 年前"],
    "_in %n hour_::_in %n hours_" : ["%n小时内"],
    "_%n hour ago_::_%n hours ago_" : ["%n小时前"],
    "_in %n minute_::_in %n minutes_" : ["%n分钟内"],
    "_%n minute ago_::_%n minutes ago_" : ["%n分钟前"],
    "in a few seconds" : "几秒钟内",
    "seconds ago" : "几秒前",
    "Empty file" : "空文件",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "模块：%s不存在。请在 App 设置中开启或联系您的管理员。",
    "Dot files are not allowed" : "以 . 开头的文件不被允许",
    "\"%1$s\" is a forbidden file or folder name." : "\"%1$s\" 是禁止的文件或文件夹名称。",
    "File already exists" : "文件已存在",
    "Invalid path" : "无效的路径",
    "Failed to create file from template" : "从模板创建文件失败",
    "Templates" : "模板",
    "Path contains invalid segments" : "路径包含无效段",
    "Filename is a reserved word" : "Filename 是保留字",
    "Filename contains at least one invalid character" : "文件名中存在至少一个非法字符",
    "Filename is too long" : "文件名太长",
    "Empty filename is not allowed" : "不允许使用空名称",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "无法安装应用\"%s\"，因为无法读取appinfo文件。",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "应用程式 \"%s\" 无法安装，因为它与这个版本的服务器不兼容。",
    "__language_name__" : "简体中文",
    "This is an automatically sent email, please do not reply." : "这是一个自动生成的电子邮件，请不要回复。",
    "Help & privacy" : "帮助&隐私",
    "Appearance and accessibility" : "外观和可访问性",
    "Apps" : "应用",
    "Personal settings" : "个人设置",
    "Administration settings" : "管理设置",
    "Settings" : "设置",
    "Log out" : "注销",
    "Accounts" : "账号",
    "Email" : "电子邮箱",
    "Mail %s" : "发邮件给 %s",
    "Fediverse" : "联邦宇宙",
    "View %s on the fediverse" : "在联邦宇宙上浏览%s",
    "Phone" : "电话",
    "Call %s" : "呼叫 %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "在Twitter上查看 %s",
    "Website" : "网站",
    "Visit %s" : "访问 %s",
    "Address" : "地址",
    "Profile picture" : "个人资料图片 ",
    "About" : "关于",
    "Display name" : "显示用户名",
    "Headline" : "标题",
    "Organisation" : "组织",
    "Role" : "角色",
    "Unknown account" : "未知帐户",
    "Additional settings" : "其他设置",
    "Enter the database Login and name for %s" : "输入 %s 的数据库登录名和名称",
    "Enter the database Login for %s" : "进入数据库登录 %s",
    "Enter the database name for %s" : "输入 %s 的数据库名称",
    "You cannot use dots in the database name %s" : "您不能在数据库名称 %s 中使用句点",
    "MySQL Login and/or password not valid" : "MySQL 用户名或密码无效",
    "You need to enter details of an existing account." : "您需要输入现有账号的详细信息。",
    "Oracle connection could not be established" : "无法建立 Oracle 连接",
    "Oracle Login and/or password not valid" : "Oracle 用户名或密码无效",
    "PostgreSQL Login and/or password not valid" : "PostgreSQL 用户名或密码无效",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X 不被支持并且 %s 在这个平台上无法正常工作。请自行承担风险！",
    "For the best results, please consider using a GNU/Linux server instead." : "为了达到最好的效果，请考虑使用 GNU/Linux 服务器。",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "看起来这个 %s 实例运行在32位 PHP 环境中并且已在 php.ini 中配置open_basedir。这将在文件超过4GB时出现问题，强烈不建议这样做。",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "请删除 php.ini 中的 open_basedir 设置或切换到64位PHP。",
    "Set an admin Login." : "设置管理员登录。",
    "Set an admin password." : "请设置一个管理员密码。",
    "Cannot create or write into the data directory %s" : "无法创建或写入数据文件夹 %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "共享后端 %s 必须实现 OCP\\Share_Backend 接口",
    "Sharing backend %s not found" : "%s 的共享后端未找到",
    "Sharing backend for %s not found" : "%s 的共享后端未找到",
    "%1$s shared »%2$s« with you" : "%1$s 对您共享了 »%2$s«",
    "%1$s shared »%2$s« with you." : "%1$s 对您共享了 »%2$s«。",
    "Click the button below to open it." : "点击下方按钮可打开它。",
    "Open »%s«" : "打开 »%s«",
    "%1$s via %2$s" : "%1$s 通过 %2$s",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s 与您共享了 »%2$s« 并希望添加：",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s 与您共享了 »%2$s« 并希望添加",
    "»%s« added a note to a file shared with you" : "»%s« 在与您共享的文件中添加了备注",
    "Passwords are enforced for link and mail shares" : "链接和邮件共享必须使用密码",
    "Unknown share type" : "未知共享类型",
    "Cannot share with yourself" : "无法与自己分享",
    "You cannot share your root folder" : "您无法共享您的主文件夹",
    "You are not allowed to share %s" : "您无权共享 %s",
    "Cannot increase permissions of %s" : "无法提升 %s 的权限",
    "Shares need at least read permissions" : "共享至少需要读取权限",
    "Files cannot be shared with delete permissions" : "不能带删除权限分享文件",
    "Files cannot be shared with create permissions" : "不能带创建权限分享文件",
    "Expiration date is in the past" : "到期日期已过",
    "Expiration date is enforced" : "强制执行到期日期",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["允许设置的最远截止期是从今天算起的 %n-1 天之后"],
    "Sharing is only allowed with group members" : "只允许与群组成员共享",
    "Sharing %s failed, because this item is already shared with the account %s" : "共享 %s 失败，因为此项目已与帐户 %s 共享",
    "Group sharing is now allowed" : "现允许群组共享",
    "Sharing is only allowed within your own groups" : "仅允许在您自己的群组内共享",
    "Path is already shared with this group" : "路径已与此群组共享",
    "Link sharing is not allowed" : "不允许共享链接",
    "Public upload is not allowed" : "不允许公开上传",
    "Path contains files shared with you" : "路径包含与您共享的文件",
    "Sharing is disabled" : "共享已禁用",
    "Sharing is disabled for you" : "已为您禁用共享",
    "Cannot share with the share owner" : "无法与共享所有者共享",
    "Share does not have a full ID" : "分享没有完整 ID",
    "Cannot change share type" : "无法更改共享类型",
    "Can only update recipient on user shares" : "仅能更新用户共享的收件人",
    "Cannot enable sending the password by Talk with an empty password" : "无法启用 Talk 发送密码功能，密码为空",
    "Cannot enable sending the password by Talk without setting a new password" : "如果不设置新密码，则无法启用通过 Talk 发送密码",
    "Cannot disable sending the password by Talk without setting a new password" : "如果不设置新密码，则无法禁用 Talk 发送密码",
    "Share provider does not support accepting" : "共享提供商不支持接受",
    "Cannot change target of link share" : "无法更改链接共享的目标",
    "The requested share does not exist anymore" : "当前请求的共享已经不存在",
    "The requested share comes from a disabled user" : "请求的分享来自一个被禁用的用户",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "由于已达用户数量上限，用户未创建。请检查通知以了解详情。",
    "Could not find category \"%s\"" : "无法找到分类 \"%s\"",
    "Sunday" : "星期日",
    "Monday" : "星期一",
    "Tuesday" : "星期二",
    "Wednesday" : "星期三",
    "Thursday" : "星期四",
    "Friday" : "星期五",
    "Saturday" : "星期六",
    "Sun." : "周日",
    "Mon." : "周一",
    "Tue." : "周二",
    "Wed." : "周三",
    "Thu." : "周四",
    "Fri." : "周五",
    "Sat." : "周六",
    "Su" : "日",
    "Mo" : "一",
    "Tu" : "二",
    "We" : "三",
    "Th" : "四",
    "Fr" : "五",
    "Sa" : "六",
    "January" : "一月",
    "February" : "二月",
    "March" : "三月",
    "April" : "四月",
    "May" : "五月",
    "June" : "六月",
    "July" : "七月",
    "August" : "八月",
    "September" : "九月",
    "October" : "十月",
    "November" : "十一月",
    "December" : "十二月",
    "Jan." : "一月",
    "Feb." : "二月",
    "Mar." : "三月",
    "Apr." : "四月",
    "May." : "五月",
    "Jun." : "六月",
    "Jul." : "七月",
    "Aug." : "八月",
    "Sep." : "九月",
    "Oct." : "十月",
    "Nov." : "十一月",
    "Dec." : "十二月",
    "A valid password must be provided" : "必须提供合法的密码",
    "The Login is already being used" : "登录名已被使用",
    "Could not create account" : "无法创建帐户",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "登录名中仅允许使用以下字符：\"a-z\", \"A-Z\", \"0-9\", 空格, \"_.@-'\"",
    "A valid Login must be provided" : "必须提供有效的登录名",
    "Login contains whitespace at the beginning or at the end" : "登录名开头或结尾包含空格",
    "Login must not consist of dots only" : "登录名不能仅由点组成",
    "Login is invalid because files already exist for this user" : "登录无效，因为此用户的文件已存在",
    "Account disabled" : "帐户已禁用",
    "Login canceled by app" : "已通过应用取消登录",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "应用 \"%1$s\" 无法安装，因为不能满足以下依赖： %2$s",
    "a safe home for all your data" : "给您所有数据一个安全的家",
    "Application is not enabled" : "应用程序未启用",
    "Authentication error" : "认证出错",
    "Token expired. Please reload page." : "Token 过期，请刷新页面。",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "没有安装数据库驱动（SQLite、MySQL 或 PostgreSQL）。",
    "Cannot write into \"config\" directory." : "无法写入 \"config\" 目录。",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "通常可以为 Web 服务器授予对 config 目录的写入权限来修复这个问题。查看 %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "或者，如果希望保持 config.php 文件的只读权限，请将 \"config_is_read_only\" 设置为 true。查看 %s",
    "Cannot write into \"apps\" directory." : "无法写入 \"apps\" 目录。",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "通常可以为 Web 服务器授予对 apps 目录的写入权限来修复这个问题，或在设置文件中禁用应用商店。",
    "Cannot create \"data\" directory." : "无法创建 “data” 目录",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "通常可以为 Web 服务器授予对根目录的写入权限来修复这个问题。查看：%s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "通常可以为 Web 服务器授予对根目录的写入权限来修复权限问题。查看：%s。",
    "Your data directory is not writable." : "您的数据目录无法写入。",
    "Setting locale to %s failed." : "设置语言为%s失败。",
    "Please install one of these locales on your system and restart your web server." : "请在您的系统中安装下述一种语言并重启 Web 服务器。",
    "PHP module %s not installed." : "PHP %s 模块未安装。",
    "Please ask your server administrator to install the module." : "请联系您的服务器管理员安装模块。",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP 选项 \"%s\" 未设置为 \"%s\"。",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "在 php.ini 中调整该设置将导致 Nextcloud 重新运行",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code>被设置为<code>%s</code>，而不是预期的 <code>0</code>。",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "为了修正该问题，请在您的 php.ini 中设置<code>mbstring.func_overload</code>为<code>0</code>。",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP 被设置为移除内联块，这将导致多个核心应用无法访问。",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "这可能由缓存/加速器导致的，例如 Zend OPcache 或 eAccelerator。",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP 模块已经安装，但仍然显示未安装？",
    "Please ask your server administrator to restart the web server." : "请联系您的服务器管理员重启 Web 服务器。",
    "The required %s config variable is not configured in the config.php file." : "所需要的配置变量 %s 没有在 config.php 文件中配置。",
    "Please ask your server administrator to check the Nextcloud configuration." : "请联系您的服务器管理员检查 Nextcloud 设置。",
    "Your data directory is readable by other people." : "您的数据目录可供其他人读取。",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "请将权限更改为 0770，以便其他人无法列出该目录。",
    "Your data directory must be an absolute path." : "您的数据目录必须是绝对路径。",
    "Check the value of \"datadirectory\" in your configuration." : "请检查配置文件中 \"datadirectory\" 的值。",
    "Your data directory is invalid." : "您的数据目录无效。",
    "Ensure there is a file called \"%1$s\" in the root of the data directory. It should have the content: \"%2$s\"" : "确保数据目录的根目录中有一个名为\"%1$s\"的文件。它应该包含以下内容：\"%2$s\"",
    "Action \"%s\" not supported or implemented." : "操作 \"%s\" 不支持或未实现。",
    "Authentication failed, wrong token or provider ID given" : "认证失败，提供了错误的token或提供者ID",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "缺少参数来完成请求。缺少的参数为：\"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID“%1$s”已被联合云提供商“%2$s”使用",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "ID为“%s”的联合云提供商不存在。",
    "Could not obtain lock type %d on \"%s\"." : "无法在 \"%s\" 上获取锁类型 %d。",
    "Storage unauthorized. %s" : "存储认证失败。%s",
    "Storage incomplete configuration. %s" : "存储未完成配置。%s",
    "Storage connection error. %s" : "存储连接错误。%s",
    "Storage is temporarily not available" : "存储暂时不可用",
    "Storage connection timeout. %s" : "存储连接超时。%s",
    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "要允许此检查运行，您必须确保您的 Web 服务器可以连接到自身。因此，它必须能够解析并连接到其 \"trusted_domains\" 或 \"overwrite.cli.url\" 中的至少一个。此失败可能是服务器端 DNS 不匹配或出站防火墙规则的结果。",
    "Transcribe audio" : "转写音频",
    "Transcribe the things said in an audio" : "将音频中的内容转录下来",
    "Audio input" : "音频输入",
    "The audio to transcribe" : "要转录的音频",
    "Context write" : "文本撰写",
    "Writes text in a given style based on the provided source material." : "通过给出语料的风格生成文字",
    "Writing style" : "撰写风格",
    "Demonstrate a writing style that you would like to immitate" : "展示你想模仿的写作风格",
    "Source material" : "来源材料",
    "The content that would like to be rewritten in the new writing style" : "希望以新文风重写的内容",
    "The generated text with content from the source material in the given style" : "生成的文本内容来自给定风格的源材料",
    "The generated emoji based on the input text" : "根据输入文本生成的表情符号",
    "Generate image" : "生成图片",
    "Generate an image from a text prompt" : "根据文本提示生成图像",
    "Prompt" : "提示",
    "Describe the image you want to generate" : "描述你想要生成的图像",
    "Runs an arbitrary prompt through a language model that returns a reply" : "通过语言模型运行任意提示并返回答复",
    "Define rules and assumptions that the assistant should follow during the conversation." : "定义助手在对话过程中应遵循的规则和假设。",
    "The history of chat messages before the current message, starting with a message by the user" : "当前消息之前的聊天消息历史记录，从用户发送的消息开始",
    "Generate a headline" : "生成标题",
    "Generates a possible headline for a text." : "为一段文本生成一个可能的标题",
    "The original text to generate a headline for" : "需要生成标题的原始文本",
    "The generated headline" : "生成的标题",
    "Reformulate text" : "重新表述文本",
    "Takes a text and reformulates it" : "获取文本并将其重新表述",
    "Write a text that you want the assistant to reformulate" : "写下您希望云助手重新表述的文本",
    "Reformulated text" : "重新表述的文本",
    "The reformulated text, written by the assistant" : "由云助手撰写的重新表述的文本",
    "Summarize" : "总结归纳",
    "Summarizes a text" : "总结一段文本",
    "The original text to summarize" : "需要总结的原始文本",
    "Summary" : "概况",
    "Extract topics" : "提取主题",
    "Extracts topics from a text and outputs them separated by commas" : "从文本中提取主题并输出，以逗号分隔",
    "The original text to extract topics from" : "需要提取主题的原始文本",
    "The list of extracted topics" : "提取的主题列表",
    "Translate" : "翻译",
    "The text to translate" : "需要翻译的文本",
    "The language of the origin text" : "原始文本语言",
    "Target language" : "目标语言",
    "The desired language to translate the origin text in" : "需要翻译的目标语言",
    "Result" : "结果",
    "Free prompt" : "自由提示",
    "Runs an arbitrary prompt through the language model." : "向语言模型中输入任何提示词",
    "Generate headline" : "生成标题",
    "Summarizes text by reducing its length without losing key information." : "总结一段文本以减少长度而不丢失关键信息",
    "Extracts topics from a text and outputs them separated by commas." : "从文本中摘出主题，输出逗号分隔的结果",
    "Education Edition" : "教育版",
    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "登录用户必须是管理员、子管理员或具有访问此设置的特殊权限",
    "Logged in user must be an admin or sub admin" : "当前登录用户必须为管理员或子管理员",
    "Logged in user must be an admin" : "当前登录用户必须为管理员",
    "File name is a reserved word" : "文件名包含敏感字符",
    "File name contains at least one invalid character" : "文件名中存在至少一个非法字符",
    "File name is too long" : "文件名过长",
    "Help" : "帮助",
    "Users" : "用户",
    "Unknown user" : "未知用户",
    "Enter the database username and name for %s" : "输入 %s 的数据库用户名和名称",
    "Enter the database username for %s" : "输入 %s 的数据库用户名",
    "MySQL username and/or password not valid" : "MySQL 数据库用户名和/或密码无效",
    "Oracle username and/or password not valid" : "Oracle 数据库用户名和/或密码无效",
    "PostgreSQL username and/or password not valid" : "PostgreSQL 数据库用户名和/或密码无效",
    "Set an admin username." : "请设置一个管理员用户名。",
    "Sharing %s failed, because this item is already shared with user %s" : "共享 %s 失败了，因为该项目已和用户 %s 进行了分享。",
    "The username is already being used" : "用户名已被使用",
    "Could not create user" : "无法创建用户",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "在用户名中只允许使用以下字符：“a-z”、“A-Z”、“0-9”、空格和 \"_.@-'\"",
    "A valid username must be provided" : "必须提供合法的用户名",
    "Username contains whitespace at the beginning or at the end" : "用户名在开头或结尾处包含空格",
    "Username must not consist of dots only" : "用户名不能仅由点组成",
    "Username is invalid because files already exist for this user" : "用户名无效，因为该用户已经存在文件",
    "User disabled" : "用户已禁用",
    "File is currently busy, please try again later" : "文件当前正忙，请稍后再试",
    "Cannot download file" : "无法下载文件",
    "Your data directory is readable by other users." : "您的数据目录可被其他用户读取。",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "请更改权限为 0770 以避免其他用户查看目录。",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "请确定在根目录下有一个名为\".ocdata\"的文件。"
},
"nplurals=1; plural=0;");
